#!/usr/bin/env python3

import rospy
from std_msgs.msg import String

def talker():
    """
    Funzione per pubblicare messaggi di tipo String sul topic '/chatter'.

    Effetto:
        - Inizializza un nodo ROS chiamato 'talker_ISC'.
        - Crea un publisher che pubblica messaggi di tipo String sul topic '/chatter'.
        - Pubblica messaggi 'hello world' con il timestamp corrente ogni secondo.
    """
    topic_des = '/chatter'  # il path del topic
    pub = rospy.Publisher(topic_des, String, queue_size=10)  # Instanzia publisher ROS

    rospy.init_node('talker_ISC', anonymous=False)  # Inizializza il nodo ROS "talker_ISC"
    rate = rospy.Rate(1)  # 1hz (1 messaggio al secondo)

    # Crea un oggetto messaggio
    string_msg = String()

    while not rospy.is_shutdown():  # Continua finché il nodo ROS non viene chiuso
        hello_str = "hello world %s" % rospy.get_time()  # Crea la stringa del messaggio con il timestamp
        rospy.loginfo("Pubblico: %s nel topic: %s" % (hello_str, topic_des))  # Stampa un messaggio di log

        # Assegna i dati al campo del messaggio
        string_msg.data = hello_str

        # Pubblica
        pub.publish(string_msg)  # Pubblica il messaggio sul topic
        rate.sleep()  # Mette in pausa per rispettare la frequenza di 1Hz

if __name__ == '__main__':
    """
    Punto di ingresso dello script.
    Chiama la funzione 'talker' e gestisce l'interruzione del nodo.
    """
    try:
        talker()  # Chiama la funzione talker()
    except rospy.ROSInterruptException:  # Gestisce l'interruzione del nodo (CTRL+C)
        pass
