#!/usr/bin/env python3

import rospy
from std_msgs.msg import String

def callback(data):
    """
    Funzione di callback chiamata quando un nuovo messaggio viene ricevuto sul topic.

    Args:
        data (std_msgs.msg.String): Il messaggio ricevuto.

    Effetto:
        Stampa un messaggio di log con il nome del nodo chiamante e il contenuto del messaggio.
    """
    rospy.loginfo(rospy.get_caller_id() + ", Ho letto %s", data.data)

def listener():
    """
    Funzione principale del nodo listener.

    Effetto:
        Inizializza il nodo ROS, si iscrive al topic '/chatter' e attende i messaggi.
        La funzione di callback 'callback' viene chiamata quando un messaggio viene ricevuto.
    """
    topic_des = "/chatter"
    rospy.init_node('listener', anonymous=True)

    rospy.Subscriber(topic_des, String, callback)

    rospy.spin()

if __name__ == '__main__':
    """
    Punto di ingresso dello script.
    Chiama la funzione 'listener' per avviare il nodo.
    """
    listener()
